%define debug_package %{nil}
%define PatchedAsOf     20230417
%global _build_id_links	none

%if 0%{?centos}0%{?amzn} == 70
%define python3_pkgversion 38
%endif

Summary:	Tools for the extraction of digital artifacts from volatile memory (RAM) images

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		Volatility3
Version:	2.4.2
Release:	2%{?dist}

License:	GPL

Group:		Applications/Forensics Tools
URL:		https://github.com/volatilityfoundation/volatility3

Source0:	%{name}-%{version}.tar.gz
Patch0:		%{name}-%{version}-patch-paths
Patch1:		%{name}-%{version}-patch-%{PatchedAsOf}

BuildRoot:	%{buildroot}
%if 0%{?fedora} >= 33
BuildRequires:	python%{python3_pkgversion}-virtualenv python3.8
%endif
%if 0%{?fedora} == 32 || 0%{?fedora} == 31
BuildRequires:	python%{python3_pkgversion}-virtualenv python%{python3_pkgversion}-devel
%endif
%if 0%{?centos} == 8 || 0%{?rhel} == 8
BuildRequires:	python%{python3_pkgversion}-virtualenv python38-devel
%endif
%if 0%{?centos} == 9 || 0%{?rhel} == 9
BuildRequires:	python3-virtualenv python3-devel python3
%endif
%if 0%{?centos}0%{?amzn} == 70 || 0%{?rhel}0%{?amzn} == 70
BuildRequires:	python36-virtualenv rh-python%{python3_pkgversion}-python-devel rh-python%{python3_pkgversion}-python-libs
%endif
%if 0%{?amzn}
BuildRequires:  rh-python36-python-virtualenv
BuildRequires:  python3 python3-devel
Requires:       python3
%endif
BuildRequires:	gcc upx openssl-devel

%description
The Volatility Framework is a completely open collection of tools,
implemented in Python under the GNU General Public License, for the
extraction of digital artifacts from volatile memory (RAM) images. The
extraction techniques are performed completely independent of the system
being investigated but offer unprecedented visibilty into the runtime
state of the system. The framework is intended to introduce people to the
techniques and complexities associated with extracting digital artifacts
from volatile memory images and provide a platform for further work into
this exciting area of research.

The Volatility Framework demonstrates our committment to and belief
in the importance of open source digital investigation tools. Volatile
Systems is committed to the belief that the technical procedures used to
extract digital evidence should be open to peer analysis and review. We
also believe this is in the best interest of the digital investigation
community, as it helps increase the communal knowledge about systems we
are forced to investigate. Similarly, we do not believe the availability
of these tools should be restricted and therefore encourage people to
modify, extend, and make derivative works, as permitted by the GPL.

%prep
%autosetup -p1 -n volatility3-%{version}
sed --in-place "s/VERSION_SUFFIX = \"\"/VERSION_SUFFIX = \": Patched as of %PatchedAsOf\"/" volatility3/framework/constants/__init__.py

%build
%if 0%{?amzn}
echo virtualenv -p $(which python3) VE  | scl enable rh-python36 -
%endif
%if 0%{?fedora} >= 33
virtualenv -p python3.8 VE
%endif
%if 0%{?fedora} == 32 || 0%{?fedora} == 31 || 0%{?centos} == 9 || 0%{?rhel} == 9
virtualenv VE
%endif
%if 0%{?centos} == 8 || 0%{?rhel} == 8
virtualenv -p python3.8 VE
%endif
%if 0%{?centos}0%{?amzn} == 70 || 0%{?rhel}0%{?amzn} == 70
virtualenv-3 -p $(echo which python3 | scl enable rh-python38 -) VE
sudo ln /opt/rh/rh-python38/root/usr/lib64/libpython3.* /opt/rh/rh-python38/root/usr/lib
%endif
sh -c "source VE/bin/activate; pip3 install --upgrade pip"
sh -c "source VE/bin/activate; pip3 install pefile pycrypto pycryptodome yara-python 'pyinstaller<5.0.0'"
sh -c "source VE/bin/activate; pyinstaller -F vol.spec"
%if 0%{?centos}0%{?amzn} == 70 || 0%{?rhel}0%{?amzn} == 70
sudo rm -f /opt/rh/rh-python38/root/usr/lib/libpython3.*
%endif
dist/vol -h

%install
%__install -d %{buildroot}%{_bindir}
%__install -m 755 dist/vol %{buildroot}%{_bindir}/vol3

%clean
# %{__rm} -rf %{buildroot}

%files
%{_bindir}/*

%changelog
* Mon Apr 17 2023 Lawrence R. Rogers <lrr@cert.org> 2.4.2-2
* Release 2.4.2-2
	Version 2.4.2 as of 2023-04-17

* Thu Mar  9 2023 Lawrence R. Rogers <lrr@cert.org> 2.4.2-1
* Release 2.4.2-1
	Version 2.4.2 as of 2023-03-09

* Fri Sep 23 2022 Lawrence R. Rogers <lrr@cert.org> 2.4.0-1
* Release 2.4.0-1
	Version 2.4.0 as of 2022-09-23

* Wed Aug 31 2022 Lawrence R. Rogers <lrr@cert.org> 2.3.1-1
* Release 2.3.1-1
	Version 2.3.1

* Tue Jul  5 2022 Lawrence R. Rogers <lrr@cert.org> 2.3.0-1
* Release 2.3.0-1
	Version 2.3.0

* Fri Jul  1 2022 Lawrence R. Rogers <lrr@cert.org> 2.2.0-2
* Release 2.2.0-2
	Version 2.2.0-2 - Patched as of 2022-07-01

* Fri May 27 2022 Lawrence R. Rogers <lrr@cert.org> 2.2.0-1
* Release 2.2.0-1
	Version 2.2.0-1

* Thu Apr 28 2022 Lawrence R. Rogers <lrr@cert.org> 2.1.0-1
* Release 2.1.0-1
	Version 2.1.0-1

* Sun Mar 27 2022 Lawrence R. Rogers <lrr@cert.org> 2.0.3-1
* Release 2.0.3-1
	Version 2.0.3-1 - Patched as of 2022-04-07

* Thu Mar  3 2022 Lawrence R. Rogers <lrr@cert.org> 2.0.2-1
* Release 2.0.2-1
	Version 2.0.2-1 - Patched as of 2022-03-03

* Wed Jan 26 2022 Lawrence R. Rogers <lrr@cert.org> 2.0.0-3
* Release 2.0.0-3
	Version 2.0.0-3 - Patched as of 2022-01-26

* Wed Jan  5 2022 Lawrence R. Rogers <lrr@cert.org> 2.0.0-2
* Release 2.0.0-2
	Version 2.0.0-2 - Patched as of 2022-01-05

* Fri Oct 22 2021 Lawrence R. Rogers <lrr@cert.org> 2.0.0-1
* Release 2.0.0-1
	Version 2.0.0-1 - Patched as of 2021-10-22

* Tue Sep 28 2021 Lawrence R. Rogers <lrr@cert.org> 1.2.1-1
* Release 1.2.1-1
	Version 1.2.1-1 - Patched as of 2021-09-28

* Mon Aug 23 2021 Lawrence R. Rogers <lrr@cert.org> 1.2.0-1
* Release 1.2.0-1
	Version 1.2.0-1 - Patched as of 2021-08-23

* Mon Jul 12 2021 Lawrence R. Rogers <lrr@cert.org> 1.1.1-1
* Release 1.1.1-1
	Version 1.1.1-1 - Patched as of 2021-07-12

* Fri Jun 25 2021 Lawrence R. Rogers <lrr@cert.org> 1.0.1-3
* Release 1.0.1-3
	Version 1.0.1-3 - Patched as of 2021-06-25

* Wed Mar 10 2021 Lawrence R. Rogers <lrr@cert.org> 1.0.1-2
* Release 1.0.1-2
	Version 1.0.1-2 - Patched as of 2021-03-10

* Mon Feb  1 2021 Lawrence R. Rogers <lrr@cert.org> 1.0.1-1
* Release 1.0.1-1
	Version 1.0.1

* Wed Jan 27 2021 Lawrence R. Rogers <lrr@cert.org> 2.0.0-20210127
* Release 2.0.0-20210127
	Version 2.0.0-20210127

* Thu Dec 17 2020 Lawrence R. Rogers <lrr@cert.org> 2.0.0.b1-20201216
* Release 2.0.0.b1-20201216
	Version 2.0.0.b1-20201216 - Changed revision number to Patched As Of date style

* Wed Dec 16 2020 Lawrence R. Rogers <lrr@cert.org> 2.0.0.b1-4
* Release 2.0.0.b1-4
	Version 2.0.0.b1-4 - patched to 2020-12-16

* Mon Dec  7 2020 Lawrence R. Rogers <lrr@cert.org> 2.0.0.b1-3
* Release 2.0.0.b1-3
	Version 2.0.0.b1-3 - patched to 2020-12-07

* Mon Nov 23 2020 Lawrence R. Rogers <lrr@cert.org> 2.0.0.b1-2
* Release 2.0.0.b1-2
	Version 2.0.0.b1-2 - patched to 2020-11-23

* Tue Nov  3 2020 Lawrence R. Rogers <lrr@cert.org> 2.0.0.b1-1
* Release 2.0.0.b1-1
	Version 2.0.0.b1-1 from 2020-11-03
